NLSL: fmomnt.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
fmomnt.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
double precision function | fmomnt (ay, n, ideriv)

## Function/Subroutine Documentation

double precision function fmomnt | ( | double precision, dimension(n) | ay,
|  | integer | n,
|  | integer | ideriv
| ) |  |

Definition at line 24 of file fmomnt.f90.